# machine-learning-my-way (early access)

Machine Learning My Way (MLMY) is a list of topics and selected links aimed at a technically curious, but non-expert reader.
Topics include probability, statistics, econometrics, machine learning, neural nets, productisation, data quality, and business and social value of the above. 

Actions: 
  - [Get PDF](https://github.com/epogrebnyak/mlmw/blob/main/MLMW_Machine_Learning_My_Way_v0.4.1.pdf) or [view online](https://docs.google.com/document/d/e/2PACX-1vT9ZkQJDDimZuPgBb7_hUJ40lm8LhqzL45HwIcYRYHw0AQkwA7pcqg0AIE7Gwf3QpAnZ34-BrFrWovO/pub)
  - Subscribe for updates: <https://buttondown.email/mlmy>
  - Telegram: <https://t.me/ml_my_way>

![image](https://github.com/epogrebnyak/mlmw/assets/9265326/1a638942-5159-4231-8e38-f65a43aea0b8)
